=======================
pytest-pypom-navigation
=======================


.. image:: https://travis-ci.org/tierratelematics/pytest-pypom-navigation.svg?branch=develop
    :target: https://travis-ci.org/tierratelematics/pytest-pypom-navigation
    :alt: See Build Status on Travis CI

.. image:: https://readthedocs.org/projects/pytest-pypom-navigation/badge/?version=latest
          :target: http://pytest-pypom-navigation.readthedocs.io

.. image:: https://codecov.io/gh/tierratelematics/pytest-pypom-navigation/branch/develop/graph/badge.svg
          :target: https://codecov.io/gh/tierratelematics/pytest-pypom-navigation

.. image:: https://pyup.io/repos/github/tierratelematics/pytest-pypom-navigation/python-3-shield.svg
          :target: https://pyup.io/repos/github/tierratelematics/pytest-pypom-navigation/
          :alt: Python 3

Core engine for tierra_qa package

----

This `Pytest`_ plugin was generated with `Cookiecutter`_ along with `@hackebrot`_'s `Cookiecutter-pytest-plugin`_ template.


Features
--------

``pytest-pypom-navigation`` is not intended to be used as a standalone package.

It provides the core engine (pytest fixtures) needed by the strong opinionated scaffolding solution
called `cookiecutter-qa`_ that let you generate a fully working QA testing hello world project based on
Selenium/Splinter with just one command.

It is also used by the pytest-play_ engine for collecting variables for tests parametrization.

Tests
------------

You can run "pytest-pypom-navigation" tests via `tox`_::

    $ pip install tox
    $ tox -epy36

Contributing
------------
Contributions are very welcome. Tests can be run with `tox`_, please ensure
the coverage at least stays the same before you submit a pull request.

License
-------

Distributed under the terms of the `Apache Software License 2.0`_ license, "pytest-pypom-navigation" is free and open source software


Issues
------

If you encounter any problems, please `file an issue`_ along with a detailed description.

.. _`Cookiecutter`: https://github.com/audreyr/cookiecutter
.. _`@hackebrot`: https://github.com/hackebrot
.. _`MIT`: http://opensource.org/licenses/MIT
.. _`BSD-3`: http://opensource.org/licenses/BSD-3-Clause
.. _`GNU GPL v3.0`: http://www.gnu.org/licenses/gpl-3.0.txt
.. _`Apache Software License 2.0`: http://www.apache.org/licenses/LICENSE-2.0
.. _`cookiecutter-pytest-plugin`: https://github.com/pytest-dev/cookiecutter-pytest-plugin
.. _`file an issue`: https://github.com/tierratelematics/pytest-pypom-navigation/issues
.. _`pytest`: https://github.com/pytest-dev/pytest
.. _`tox`: https://tox.readthedocs.io/en/latest/
.. _`pip`: https://pypi.python.org/pypi/pip/
.. _`PyPI`: https://pypi.python.org/pypi
.. _`cookiecutter-qa`: https://github.com/tierratelematics/cookiecutter-qa
.. _`pytest-play`: https://github.com/tierratelematics/pytest-play
